# DollarDoc

Dollardoc is a unique documentation method that uses markdown and a pseudo object-oriented model to simplify documentation in complex environments. By utilizing dollar-plugins, dollardoc provides a featurefilled documentation method, while still being lightweight and straightforward.

Initially designed with system architecture documentation in mind, dollardoc can be easily generalized for other documentation purposes.

## Getting Started

To begin using dollardoc, set up a base Python project that installs the dollardoc dependency. You can also use the dollar-project-boilerplate project, which will provide you with a quick start.

*...Chapter under development*

### Installation

*...Chapter under development*

### Creating Your First Documentation File

*...Chapter under development*

### Building the Documentation

*...Chapter under development*

## Dollar Syntax Documentation

*...Chapter under development*

## Outputs Supported

Currently, this project only supports output for markdown files.

## Future of the Project

* **Syntax specification**
  * An outline of the syntax specification is currently in progress.

* **Better error handling**
  * Improve feedback from error messages by providing the row number in dollar-files.

* **Support for tags**
  * Add the ability to create indirect links between different pages using tags. This simplifies the process of linking related documentation pages without requiring the creation of entire new pages.
